@@ -6,13 +6,9 @@ the tags.
 
 For tag model manager, look in tagulous.models.models
 """
-from __future__ import unicode_literals
-
 from django.core import exceptions
-from django.utils import six
-from django.utils.encoding import python_2_unicode_compatible
 
-from tagulous.utils import parse_tags, render_tags
+from ..utils import parse_tags, render_tags
 
 
 # ##############################################################################
@@ -61,15 +57,8 @@ class SingleTagManager(object):
 
         Must be called after all
         """
-        # Django 2.0 changes cache management
-        if hasattr(self.field, "get_cached_value"):
-            if self.field.is_cached(self.instance):
-                self.field.delete_cached_value(self.instance)
-        else:
-            # Django <2.0
-            cache_name = self.field.get_cache_name()
-            if hasattr(self.instance, cache_name):
-                delattr(self.instance, cache_name)
+        if self.field.is_cached(self.instance):
+            self.field.delete_cached_value(self.instance)
 
     def get_actual(self):
         """
@@ -154,7 +143,7 @@ class SingleTagManager(object):
         if not value:
             tag_name = ""
 
-        elif isinstance(value, six.string_types):
+        elif isinstance(value, str):
             # Force tag to lowercase
             if self.tag_options.force_lowercase:
                 value = value.lower()
@@ -246,7 +235,6 @@ class SingleTagManager(object):
 # ##############################################################################
 
 
-@python_2_unicode_compatible
 class BaseTagRelatedManager(object):
     """
     Mixin for TagRelatedManagerMixin, and base class for FakeTagRelatedManager.
@@ -287,7 +275,7 @@ class BaseTagRelatedManager(object):
         return self.get_tag_string()
 
     def __contains__(self, item):
-        item_str = six.text_type(item)
+        item_str = str(item)
         if self.tag_options.force_lowercase:
             item_str = item_str.lower()
 
@@ -307,8 +295,8 @@ class BaseTagRelatedManager(object):
         # Prep other argument we're comparing against
         if isinstance(other, BaseTagRelatedManager):
             other = other.tags
-        if isinstance(other, six.string_types):
-            other_str = six.text_type(other)
+        if isinstance(other, str):
+            other_str = str(other)
 
             # Enforce case non-sensitivity or lowercase
             if lower:
@@ -323,7 +311,7 @@ class BaseTagRelatedManager(object):
             # Assume it's an iterable
             other_tags = other
             if lower:
-                other_tags = [six.text_type(tag).lower() for tag in other]
+                other_tags = [str(tag).lower() for tag in other]
 
         # Get list of set tags
         self_tags = self.get_tag_list()
@@ -401,7 +389,7 @@ class BaseTagRelatedManager(object):
             )
 
         # Force tag_names to strings, in case it's a list of tags or a queryset
-        tag_names = [six.text_type(tag_name) for tag_name in tag_names]
+        tag_names = [str(tag_name) for tag_name in tag_names]
 
         # Apply force_lowercase
         if self.tag_options.force_lowercase:
@@ -605,7 +593,7 @@ class TagRelatedManagerMixin(BaseTagRelatedManager):
         # Convert strings to tag objects
         new_tags = []
         for tag in objs:
-            if isinstance(tag, six.string_types):
+            if isinstance(tag, str):
                 new_tags.append(self.tag_model(name=tag))
             else:
                 new_tags.append(tag)
@@ -640,7 +628,7 @@ class TagRelatedManagerMixin(BaseTagRelatedManager):
         # Convert strings to tag objects - if object doesn't exist, skip
         rm_tags = []
         for tag in objs:
-            if isinstance(tag, six.string_types):
+            if isinstance(tag, str):
                 try:
                     rm_tags.append(self.tag_model.objects.get(name=tag))
                 except self.tag_model.DoesNotExist:
