@@ -5,12 +5,8 @@ Modules tested:
     tagulous.models.fields.TagField
     tagulous.forms.TagField
 """
-from __future__ import absolute_import, unicode_literals
-
-import django
 from django import forms
 from django.test import TestCase
-from django.utils import six
 
 from tagulous import forms as tag_forms
 from tagulous import models as tag_models
@@ -80,7 +76,7 @@ class FormTagFieldTest(TagTestManager, TestCase):
 
         form = LocalTestForm()
         self.assertHTMLEqual(
-            six.text_type(form["tag"]),
+            str(form["tag"]),
             (
                 '<input autocomplete="off" '
                 'data-tag-options="{&quot;required&quot;: true}" '
@@ -97,7 +93,7 @@ class FormTagFieldTest(TagTestManager, TestCase):
 
         form = LocalTestForm()
         self.assertHTMLEqual(
-            six.text_type(form["tag"]),
+            str(form["tag"]),
             (
                 '<input autocomplete="off" '
                 'data-tag-options="{&quot;required&quot;: false}" '
@@ -114,7 +110,7 @@ class FormTagFieldTest(TagTestManager, TestCase):
 
         form = LocalTestForm()
         self.assertHTMLEqual(
-            six.text_type(form["tag"]),
+            str(form["tag"]),
             (
                 '<input autocomplete="off" '
                 'data-tag-options="{&quot;required&quot;: true}" '
@@ -136,7 +132,7 @@ class FormTagFieldTest(TagTestManager, TestCase):
 
         form = LocalTestForm()
         self.assertHTMLEqual(
-            six.text_type(form["tag"]),
+            str(form["tag"]),
             (
                 '<input autocomplete="off" '
                 'data-tag-options="{&quot;required&quot;: true}" '
@@ -151,7 +147,7 @@ class FormTagFieldTest(TagTestManager, TestCase):
         "Check widget renders value"
         form = test_forms.TagFieldForm(data={"tags": "run, walk"})
         self.assertHTMLEqual(
-            six.text_type(form["tags"]),
+            str(form["tags"]),
             (
                 '<input autocomplete="off" '
                 'data-tag-options="{&quot;required&quot;: true}" '
@@ -172,24 +168,15 @@ class FormTagFieldTest(TagTestManager, TestCase):
 
         form = LocalTestForm()
         with self.assertRaises(ValueError) as cm:
-            six.text_type(form["tag"])
-        if django.VERSION < (1, 11):
-            self.assertTrue(
-                six.text_type(cm.exception).startswith(
-                    "Invalid autocomplete view: Reverse for '%s' with arguments '("
-                    ")' and keyword arguments '{}' not found." % autocomplete_view
-                )
-            )
-        else:
-            # Django 1.11 changes the error message
-            self.assertTrue(
-                six.text_type(cm.exception).startswith(
-                    "Invalid autocomplete view: Reverse for '{0}' not found. "
-                    "'{0}' is not a valid view function or pattern name.".format(
-                        autocomplete_view
-                    )
+            str(form["tag"])
+        self.assertTrue(
+            str(cm.exception).startswith(
+                "Invalid autocomplete view: Reverse for '{0}' not found. "
+                "'{0}' is not a valid view function or pattern name.".format(
+                    autocomplete_view
                 )
             )
+        )
 
     def test_render_autocomplete_settings(self):
         "Check widget merges autocomplete settings with defaults"
@@ -213,7 +200,7 @@ class FormTagFieldTest(TagTestManager, TestCase):
         # Render
         # Expecting bees:buzz, cats:purr, cows:moo
         self.assertHTMLEqual(
-            six.text_type(form["tags"]),
+            str(form["tags"]),
             (
                 '<input autocomplete="off" '
                 'data-tag-options="{'
@@ -231,7 +218,7 @@ class FormTagFieldTest(TagTestManager, TestCase):
         with self.assertRaises(ValueError) as cm:
             form["tags"].field.prepare_value(["tag", "list", "fails"])
         self.assertEqual(
-            six.text_type(cm.exception), "Tag field could not prepare unexpected value"
+            str(cm.exception), "Tag field could not prepare unexpected value"
         )
 
 
@@ -369,7 +356,7 @@ class ModelFormTagFieldTest(TagTestManager, TestCase):
         self.assertTagModel(self.tag_model, {"red": 0, "blue": 0, "yellow": 0})
         form = self.form(data={"name": "Test 1", "tags": "red, blue"})
         self.assertHTMLEqual(
-            six.text_type(form["tags"]),
+            str(form["tags"]),
             (
                 '<input autocomplete="off" '
                 'data-tag-options="{&quot;required&quot;: true}" '
@@ -385,7 +372,7 @@ class ModelFormTagFieldTest(TagTestManager, TestCase):
         "Check initial tag string"
         form = test_forms.TagFieldForm(initial={"tags": "red, blue"})
         self.assertHTMLEqual(
-            six.text_type(form["tags"]),
+            str(form["tags"]),
             (
                 '<input autocomplete="off" '
                 'data-tag-options="{&quot;required&quot;: true}" '
@@ -401,7 +388,7 @@ class ModelFormTagFieldTest(TagTestManager, TestCase):
         t2 = self.tag_model.objects.create(name="blue")
         form = test_forms.TagFieldForm(initial={"tags": [t1, t2]})
         self.assertHTMLEqual(
-            six.text_type(form["tags"]),
+            str(form["tags"]),
             (
                 '<input autocomplete="off" '
                 'data-tag-options="{&quot;required&quot;: true}" '
@@ -418,7 +405,7 @@ class ModelFormTagFieldTest(TagTestManager, TestCase):
         tags = self.tag_model.objects.all()
         form = test_forms.TagFieldForm(initial={"tags": tags})
         self.assertHTMLEqual(
-            six.text_type(form["tags"]),
+            str(form["tags"]),
             (
                 '<input autocomplete="off" '
                 'data-tag-options="{&quot;required&quot;: true}" '
@@ -435,7 +422,7 @@ class ModelFormTagFieldTest(TagTestManager, TestCase):
         form = self.form(instance=t1)
 
         self.assertHTMLEqual(
-            six.text_type(form["tags"]),
+            str(form["tags"]),
             (
                 '<input autocomplete="off" '
                 'data-tag-list="[&quot;blue&quot;, &quot;red&quot;]" '
@@ -462,7 +449,7 @@ class ModelFormTagFieldTest(TagTestManager, TestCase):
         form["two"].field.widget.default_autocomplete_settings = {"bees": "buzz"}
 
         self.assertHTMLEqual(
-            six.text_type(form["two"]),
+            str(form["two"]),
             (
                 '<input autocomplete="off" '
                 'data-tag-list="[]" '
@@ -517,7 +504,7 @@ class ModelFormTagFieldRequiredTest(TagTestManager, TestCase):
         t1 = form.save()
         self.assertEqual(t1.name, "Test 1")
         self.assertEqual(t1.tag, "blue, red")
-        self.assertEqual(six.text_type(t1.tag), "blue, red")
+        self.assertEqual(str(t1.tag), "blue, red")
         self.assertIsInstance(t1.tag, tag_models.TagRelatedManagerMixin)
         self.assertEqual(t1.tag.count(), 2)
         self.assertEqual(t1.tag.all()[0], "blue")
